.. _authors:

Authors
=======

To see who contributed to LSTOSA repository, please visit the
`contributors page <https://github.com/cta-observatory/lstosa/graphs/contributors>`__
(in alphabetical order):

* Andrés Baquero, UCM, Spain
* María Láinez, UCM, Spain
* Daniel Morcuende, UCM, Spain
* José Enrique Ruiz, IAA-CSIC, Spain
* José Luis Contreras, UCM, Spain
* Lab Saha, UCM, Spain

We thank also Isidro Aguado (UCM, Spain) for his invaluable help and technical support.

LSTOSA was started by Lab Saha and José Luis Contreras (Madrid, UCM) adapting the MAGIC On-site Analysis
pipeline (MAGIC OSA) to the LST analysis pipeline. Since LSTOSA framework is heavily based on
MAGIC OSA, a big portion of the credits goes to the authors of MAGIC OSA (Alejandro Lorca,
José Luis Contreras, Raquel de los Reyes, Igor Oya, Daniel Nieto, S. Pardo, Konstancja Satalecka,
David Fidalgo, Mireia Nievas and Lab Saha).
